==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1NodeSelectorFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1NodeSelectorFluent<A extends V1NodeSelectorFluent<A>> extends Fluent<A>{


    public A addToNodeSelectorTerms(int index,V1NodeSelectorTerm item);
    public A setToNodeSelectorTerms(int index,V1NodeSelectorTerm item);
    public A addToNodeSelectorTerms(V1NodeSelectorTerm... items);
    public A addAllToNodeSelectorTerms(Collection<V1NodeSelectorTerm> items);
    public A removeFromNodeSelectorTerms(V1NodeSelectorTerm... items);
    public A removeAllFromNodeSelectorTerms(Collection<V1NodeSelectorTerm> items);
    
/**
 * This method has been deprecated, please use method buildNodeSelectorTerms instead.
 * @return The buildable object.
 */
@Deprecated public List<V1NodeSelectorTerm> getNodeSelectorTerms();
    public List<V1NodeSelectorTerm> buildNodeSelectorTerms();
    public V1NodeSelectorTerm buildNodeSelectorTerm(int index);
    public V1NodeSelectorTerm buildFirstNodeSelectorTerm();
    public V1NodeSelectorTerm buildLastNodeSelectorTerm();
    public V1NodeSelectorTerm buildMatchingNodeSelectorTerm(io.kubernetes.client.fluent.Predicate<V1NodeSelectorTermBuilder> predicate);
    public A withNodeSelectorTerms(List<V1NodeSelectorTerm> nodeSelectorTerms);
    public A withNodeSelectorTerms(V1NodeSelectorTerm... nodeSelectorTerms);
    public Boolean hasNodeSelectorTerms();
    public V1NodeSelectorFluent.NodeSelectorTermsNested<A> addNewNodeSelectorTerm();
    public V1NodeSelectorFluent.NodeSelectorTermsNested<A> addNewNodeSelectorTermLike(V1NodeSelectorTerm item);
    public V1NodeSelectorFluent.NodeSelectorTermsNested<A> setNewNodeSelectorTermLike(int index,V1NodeSelectorTerm item);
    public V1NodeSelectorFluent.NodeSelectorTermsNested<A> editNodeSelectorTerm(int index);
    public V1NodeSelectorFluent.NodeSelectorTermsNested<A> editFirstNodeSelectorTerm();
    public V1NodeSelectorFluent.NodeSelectorTermsNested<A> editLastNodeSelectorTerm();
    public V1NodeSelectorFluent.NodeSelectorTermsNested<A> editMatchingNodeSelectorTerm(io.kubernetes.client.fluent.Predicate<V1NodeSelectorTermBuilder> predicate);

    public interface NodeSelectorTermsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1NodeSelectorTermFluent<V1NodeSelectorFluent.NodeSelectorTermsNested<N>>{

        
    public N and();    public N endNodeSelectorTerm();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1NodeSelectorFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1NodeSelectorFluent<A extends V1NodeSelectorFluent<A>> extends Fluent<A>{


    public A addToNodeSelectorTerms(int index,V1NodeSelectorTerm item);
    public A setToNodeSelectorTerms(int index,V1NodeSelectorTerm item);
    public A addToNodeSelectorTerms(V1NodeSelectorTerm... items);
    public A addAllToNodeSelectorTerms(Collection<V1NodeSelectorTerm> items);
    public A removeFromNodeSelectorTerms(V1NodeSelectorTerm... items);
    public A removeAllFromNodeSelectorTerms(Collection<V1NodeSelectorTerm> items);
    
/**
 * This method has been deprecated, please use method buildNodeSelectorTerms instead.
 * @return The buildable object.
 */
@Deprecated public List<V1NodeSelectorTerm> getNodeSelectorTerms();
    public List<V1NodeSelectorTerm> buildNodeSelectorTerms();
    public V1NodeSelectorTerm buildNodeSelectorTerm(int index);
    public V1NodeSelectorTerm buildFirstNodeSelectorTerm();
    public V1NodeSelectorTerm buildLastNodeSelectorTerm();
    public V1NodeSelectorTerm buildMatchingNodeSelectorTerm(io.kubernetes.client.fluent.Predicate<V1NodeSelectorTermBuilder> predicate);
    public Boolean hasMatchingNodeSelectorTerm(io.kubernetes.client.fluent.Predicate<V1NodeSelectorTermBuilder> predicate);
    public A withNodeSelectorTerms(List<V1NodeSelectorTerm> nodeSelectorTerms);
    public A withNodeSelectorTerms(V1NodeSelectorTerm... nodeSelectorTerms);
    public Boolean hasNodeSelectorTerms();
    public V1NodeSelectorFluent.NodeSelectorTermsNested<A> addNewNodeSelectorTerm();
    public V1NodeSelectorFluent.NodeSelectorTermsNested<A> addNewNodeSelectorTermLike(V1NodeSelectorTerm item);
    public V1NodeSelectorFluent.NodeSelectorTermsNested<A> setNewNodeSelectorTermLike(int index,V1NodeSelectorTerm item);
    public V1NodeSelectorFluent.NodeSelectorTermsNested<A> editNodeSelectorTerm(int index);
    public V1NodeSelectorFluent.NodeSelectorTermsNested<A> editFirstNodeSelectorTerm();
    public V1NodeSelectorFluent.NodeSelectorTermsNested<A> editLastNodeSelectorTerm();
    public V1NodeSelectorFluent.NodeSelectorTermsNested<A> editMatchingNodeSelectorTerm(io.kubernetes.client.fluent.Predicate<V1NodeSelectorTermBuilder> predicate);

    public interface NodeSelectorTermsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1NodeSelectorTermFluent<V1NodeSelectorFluent.NodeSelectorTermsNested<N>>{

        
    public N and();    public N endNodeSelectorTerm();
}


}
